/***********************************************************************************************************************
 *
 * blueBill Mobile - open source birdwatching
 * ==========================================
 *
 * Copyright (C) 2009, 2010 by Tidalwave s.a.s. (http://www.tidalwave.it)
 * http://bluebill.tidalwave.it/mobile/
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * $Id: Location.java,v ae0dde520a82 2010/06/07 21:30:49 fritz $
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.observation;

import javax.annotation.Nonnull;
import java.io.Serializable;
import it.tidalwave.util.As;
import it.tidalwave.util.Displayable;
import org.openide.util.Lookup;

/*******************************************************************************
 *
 * Represents the location where an
 * {@link Observation} or an {@link ObservationItem} has been made.
 *
 * @author  Fabrizio Giudici
 * @version $Id: Location.java,v ae0dde520a82 2010/06/07 21:30:49 fritz $
 *
 ******************************************************************************/
public interface Location extends Displayable, Lookup.Provider, Serializable, As
  {
    public static final Class<Location> Location = Location.class;

    /***************************************************************************
     *
     * Returns a {@link Finder} for {@link ObservationItem}s that have been made
     * at this {@code Location}.
     *
     * @return  the {@link Finder}
     *
     **************************************************************************/
    @Nonnull
    public Finder<ObservationItem> findObservationItems();

    /***************************************************************************
     *
     * Returns a {@link Finder} for {@link Observation}s that have been made
     * at this {@code Location}.
     *
     * @return  the {@link Finder}
     *
     **************************************************************************/
    @Nonnull
    public Finder<Observation> findObservations(); 
  }
